sqlobject.tests.test_jsoncol module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_jsoncol module

class `sqlobject.tests.test_jsoncol.` `JSONTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = json_test
  property `json`
  `q` = json_test
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_jsoncol.JSONTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'json_test'

`sqlobject.tests.test_jsoncol.` `test_JSONCol`()

`sqlobject.tests.test_jsoncol.` `test_JSONCol_funcs`()